==> jboss-seam-ui-2.1.0.GA-sources.jar: org/jboss/seam/ui/component/html/HtmlEqualityValidator.java <==
package org.jboss.seam.ui.component.html;

import javax.el.ELException;
import javax.el.ValueExpression;
import javax.faces.FacesException;
import javax.faces.context.FacesContext;
import org.jboss.seam.ui.component.UIEqualityValidator;

public class HtmlEqualityValidator extends UIEqualityValidator{

static public final  String COMPONENT_FAMILY = "org.jboss.seam.ui.EqualityValidator";

static public final  String COMPONENT_TYPE = "org.jboss.seam.ui.EqualityValidator";

/*
* Id of component to validate against
*/
private  String _for = null;

/*
* Error message to show
*/
private  String _message = null;

/*
* Message id to use on failure
*/
private  String _messageId = null;


public HtmlEqualityValidator(){
setRendererType("org.jboss.seam.ui.EqualityValidatorRenderer");
}

public String getFor(){
	if (this._for != null) {
		return this._for;
	}
	ValueExpression ve = getValueExpression("for");
	if (ve != null) {
	    String value = null;
	    
	    try {
			value = (String) ve.getValue(getFacesContext().getELContext());
	    } catch (ELException e) {
			throw new FacesException(e);
	    }
	    
	    return value;
	} 

    return null;
	

}

public void setFor(String _for){
this._for = _for;
}

public String getMessage(){
	if (this._message != null) {
		return this._message;
	}
	ValueExpression ve = getValueExpression("message");
	if (ve != null) {
	    String value = null;
	    
	    try {
			value = (String) ve.getValue(getFacesContext().getELContext());
	    } catch (ELException e) {
			throw new FacesException(e);
	    }
	    
	    return value;
	} 

    return null;
	

}

public void setMessage(String _message){
this._message = _message;
}

public String getMessageId(){
	if (this._messageId != null) {
		return this._messageId;
	}
	ValueExpression ve = getValueExpression("messageId");
	if (ve != null) {
	    String value = null;
	    
	    try {
			value = (String) ve.getValue(getFacesContext().getELContext());
	    } catch (ELException e) {
			throw new FacesException(e);
	    }
	    
	    return value;
	} 

    return null;
	

}

public void setMessageId(String _messageId){
this._messageId = _messageId;
}

public String getFamily(){
return COMPONENT_FAMILY;
}

@Override
public Object saveState(FacesContext context){
Object [] state = new Object[4];
state[0] = super.saveState(context);
state[1] = _for;
state[2] = _message;
state[3] = _messageId;
return state;
}

@Override
public void restoreState(FacesContext context, Object state){
Object[] states = (Object[]) state;
super.restoreState(context, states[0]);
	_for = (String)states[1];;
		_message = (String)states[2];;
		_messageId = (String)states[3];;
	
}

}

==> jboss-seam-ui-2.1.1.GA-sources.jar: org/jboss/seam/ui/component/html/HtmlEqualityValidator.java <==
package org.jboss.seam.ui.component.html;

import javax.el.ELException;
import javax.el.ValueExpression;
import javax.faces.FacesException;
import javax.faces.context.FacesContext;
import org.jboss.seam.ui.component.UIEqualityValidator;

public class HtmlEqualityValidator extends UIEqualityValidator{

static final public  String COMPONENT_FAMILY = "org.jboss.seam.ui.EqualityValidator";

static final public  String COMPONENT_TYPE = "org.jboss.seam.ui.EqualityValidator";

/*
* Id of component to validate against
*/
private  String _for = null;

/*
* Error message to show
*/
private  String _message = null;

/*
* Message id to use on failure
*/
private  String _messageId = null;

/*
* Operation to use.
*/
private  String _operator = null;


public HtmlEqualityValidator(){
setRendererType("org.jboss.seam.ui.EqualityValidatorRenderer");
}

public String getFor(){
	if (this._for != null) {
		return this._for;
	}
	ValueExpression ve = getValueExpression("for");
	if (ve != null) {
	    String value = null;
	    
	    try {
			value = (String) ve.getValue(getFacesContext().getELContext());
	    } catch (ELException e) {
			throw new FacesException(e);
	    }
	    
	    return value;
	} 

    return null;
	

}

public void setFor(String _for){
this._for = _for;
}

public String getMessage(){
	if (this._message != null) {
		return this._message;
	}
	ValueExpression ve = getValueExpression("message");
	if (ve != null) {
	    String value = null;
	    
	    try {
			value = (String) ve.getValue(getFacesContext().getELContext());
	    } catch (ELException e) {
			throw new FacesException(e);
	    }
	    
	    return value;
	} 

    return null;
	

}

public void setMessage(String _message){
this._message = _message;
}

public String getMessageId(){
	if (this._messageId != null) {
		return this._messageId;
	}
	ValueExpression ve = getValueExpression("messageId");
	if (ve != null) {
	    String value = null;
	    
	    try {
			value = (String) ve.getValue(getFacesContext().getELContext());
	    } catch (ELException e) {
			throw new FacesException(e);
	    }
	    
	    return value;
	} 

    return null;
	

}

public void setMessageId(String _messageId){
this._messageId = _messageId;
}

public String getOperator(){
	if (this._operator != null) {
		return this._operator;
	}
	ValueExpression ve = getValueExpression("operator");
	if (ve != null) {
	    String value = null;
	    
	    try {
			value = (String) ve.getValue(getFacesContext().getELContext());
	    } catch (ELException e) {
			throw new FacesException(e);
	    }
	    
	    return value;
	} 

    return null;
	

}

public void setOperator(String _operator){
this._operator = _operator;
}

public String getFamily(){
return COMPONENT_FAMILY;
}

@Override
public Object saveState(FacesContext context){
Object [] state = new Object[5];
state[0] = super.saveState(context);
state[1] = _for;
state[2] = _message;
state[3] = _messageId;
state[4] = _operator;
return state;
}

@Override
public void restoreState(FacesContext context, Object state){
Object[] states = (Object[]) state;
super.restoreState(context, states[0]);
	_for = (String)states[1];;
		_message = (String)states[2];;
		_messageId = (String)states[3];;
		_operator = (String)states[4];;
	
}

}
